Modify the addIntegrityData to pass the payload length

Change-Id: Ie04dec8866fc7116b5827ad691975e7e417ec684
Signed-off-by: Tom Joseph <tomjoseph@in.ibm.com>
diff --git a/message_parsers.hpp b/message_parsers.hpp
index d11dc5b..9403687 100644
--- a/message_parsers.hpp
+++ b/message_parsers.hpp
@@ -188,10 +188,12 @@
  * @brief Add Integrity data to the outgoing IPMI packet
  *
  * @param[in] packet - Outgoing IPMI packet
  * @param[in] message - IPMI Message populated from the incoming packet
  *
  */
-void addIntegrityData(std::vector<uint8_t>& packet, const Message& message);
+void addIntegrityData(std::vector<uint8_t>& packet,
+                      const Message& message,
+                      size_t payloadLen);
 
 } // namespace internal
@@ -188,10 +188,12 @@
  *
  * @param[in] packet - Outgoing IPMI packet
- * @param[in] message - IPMI Message populated from the incoming packet
- *
+ * @param[in] message - IPMI Message populated for the outgoing packet
+ * @param[in] payloadLen - Length of the IPMI payload
  */